==> kdelibs-3.3.2.tar.bz2: kdelibs-3.3.2/kabc/vcard/include/VCardParam.h <==
/*
	libvcard - vCard parsing library for vCard version 3.0
	
	Copyright (C) 1999 Rik Hemsley rik@kde.org
	
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef  PARAM_H
#define  PARAM_H

#include <qcstring.h>
#include <qptrlist.h>

#include <VCardEntity.h>

namespace VCARD
{

class Param : public Entity
{

#include "Param-generated.h"

        Param(const QCString &name, const QCString &value);

	void setName(const QCString &);
	void setValue(const QCString &);
		
	QCString name();
	QCString value();
	
	private:
		
		QCString name_;
		QCString value_;
};

typedef QPtrList<Param> ParamList;
typedef QPtrListIterator<Param> ParamListIterator;

}

#endif

==> kdelibs-3.5.10.tar.bz2: kdelibs-3.5.10/kabc/vcard/include/VCardParam.h <==
/*
	libvcard - vCard parsing library for vCard version 3.0
	
	Copyright (C) 1999 Rik Hemsley rik@kde.org
	
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef  PARAM_H
#define  PARAM_H

#include <qcstring.h>
#include <qptrlist.h>

#include <VCardEntity.h>

namespace VCARD
{

class KVCARD_EXPORT Param : public Entity
{

#include "Param-generated.h"

        Param(const QCString &name, const QCString &value);

	void setName(const QCString &);
	void setValue(const QCString &);
		
	QCString name();
	QCString value();
	
	private:
		
		QCString name_;
		QCString value_;
};

typedef QPtrList<Param> ParamList;
typedef QPtrListIterator<Param> ParamListIterator;

}

#endif
